@@ -91,16 +91,10 @@ var gMainPane = {
 
     if (win) {
       var homePage = document.getElementById("browser.startup.homepage");
-      var browser = win.document.getElementById("content");
-
-      var newVal = browser.browsers[0].currentURI.spec;
-      if (browser.browsers.length > 1) {
-        // XXX using dangerous "|" joiner!
-        for (var i = 1; i < browser.browsers.length; i++)
-          newVal += "|" + browser.browsers[i].currentURI.spec;
-      }
-
-      homePage.value = newVal;
+      var tabs = win.gBrowser.visibleTabs;
+      function getTabURI(t) t.linkedBrowser.currentURI.spec;
+      // FIXME Bug 244192: using dangerous "|" joiner!
+      homePage.value = tabs.map(getTabURI).join("|");
     }
   },
 
